@@ -296,7 +296,7 @@ def test_codegen(optstring,
                                       include_last_src)
         gen.write()
     else:
-        _error("Invaild namespace '%s'" % (namespace, ))
+        _error("Invalid namespace '%s'" % (namespace, ))
     return 0
 
 
@@ -470,6 +470,10 @@ def create_source_scanner(options, args):
     finally:
         for error in ss.get_errors():
             print(error, file=sys.stderr)
+
+    if ss.get_errors() and options.warn_fatal:
+        _error("error caught during scanner parsing")
+
     return ss, filenames
 
 
